@@ -274,6 +274,40 @@ void LocalNetworkAdjustmentResults::Parser::init()
 }
 
 
+int LocalNetworkAdjustmentResults::Parser::startElement(const char *name, const char **atts)
+{
+  check_and_clear_data();
+  attributes = atts;
+  tmp_tag = name;
+  int t = tag(name);
+  TagFun f = tagfun[state][t];
+  (this->*f)(true);
+
+  return 0;
+}
+
+
+int LocalNetworkAdjustmentResults::Parser::characterDataHandler(const char *s, int len)
+{
+  data += std::string(s, std::string::size_type(len));
+
+  return 0;
+}
+
+
+int LocalNetworkAdjustmentResults::Parser::endElement(const char * /*name*/)
+{
+  if (stack.empty()) stack.push(&Parser::unknown);
+
+  TagFun f = stack.top();
+  stack.pop();
+  (this->*f)(false);
+  data.clear();
+
+  return 0;
+}
+
+
 void LocalNetworkAdjustmentResults::Parser::unknown(bool)
 {
   error("illegal context or unknown tag <" + name + ">");
